[binutils-gdb] include: sframe: fix minor typos in sframe_decode

Indu Bhagat ibhagat@sourceware.org
Wed Nov 5 07:32:37 GMT 2025


https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=dfb31cd02bc62b5ad84d9f274d9f2e45c2640e75

commit dfb31cd02bc62b5ad84d9f274d9f2e45c2640e75
Author: Indu Bhagat <indu.bhagat@oracle.com>
Date:   Tue Nov 4 23:28:43 2025 -0800

    include: sframe: fix minor typos in sframe_decode
    
    Change argument names (in declaration) to SF_BUF and SF_SIZE (instead of
    the current CF_BUF and CF_SIZE respectively).
    
    include/
            * sframe-api.h (sframe_decode): Fix typos.  Use same name as
            used for the definition.

Diff:
---
 include/sframe-api.h | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/include/sframe-api.h b/include/sframe-api.h
index 507f806ab4c..42f140115de 100644
--- a/include/sframe-api.h
+++ b/include/sframe-api.h
@@ -103,10 +103,10 @@ sframe_calc_fre_type (size_t func_size);
 
 /* The SFrame Decoder.  */
 
 /* Decode the specified SFrame buffer CF_BUF of size CF_SIZE and return the
    new SFrame decoder context.  Sets ERRP for the caller if any error.  */
 extern sframe_decoder_ctx *
-sframe_decode (const char *cf_buf, size_t cf_size, int *errp);
+sframe_decode (const char *sf_buf, size_t sf_size, int *errp);
 
 /* Free the decoder context.  */
 extern void
@@ -103,10 +103,10 @@ sframe_calc_fre_type (size_t func_size);
 /* The SFrame Decoder.  */
 
-/* Decode the specified SFrame buffer CF_BUF of size CF_SIZE and return the
+/* Decode the specified SFrame buffer SF_BUF of size SF_SIZE and return the
    new SFrame decoder context.  Sets ERRP for the caller if any error.  */
 extern sframe_decoder_ctx *


More information about the Binutils-cvs mailing list